-- 使得文件中的函数在何处都可调用
module(...,package.seeall)

--LCD分辨率的宽度和高度(单位是像素)
WIDTH, HEIGHT, BPP = disp.getlcdinfo()

--音频播放优先级，对应audio.play接口中的priority参数；数值越大，优先级越高，用户根据自己的需求设置优先级
--PWRON：开机铃声
--CALL：来电铃声
--SMS：新短信铃声
--TTS：TTS播放
--REC:录音音频
PWRON,CALL,SMS,TTS,REC = 4,3,2,1,0

local function playTts(ttsStr)
    --单次播放，音量等级3
    audio.play(TTS,"TTS",ttsStr,3)
end

-- 用来将HttpPost内容从table格式转换为表单提交（x-www-form-urlencoded）的格式
local function urlencodeTab(params)
    local msg = {}
    for k,v in pairs(params) do
        table.insert(msg,string.urlEncode(k)..'='..string.urlEncode(v))
        table.insert(msg,'&')
    end
    table.remove(msg)
    return table.concat(msg)
end

-- http请求结果处理回调方法
local function HttpInfoHandler(result,code,head,body)

    -- 查看http请求返回状态码
    log.info("Http.Code",result,code)

    -- 遍历响应头内容
    if result and head then
        for k,v in pairs(head) do
            log.info("Http.Head",k..":"..v)
        end
    end

    if result and body then
        -- 将json字符串解析为lua中的table结构
        local tjsondata,result,errinfo = json.decode(body)
        -- 将tjsondata内容传递给全局变量weatherInfo方便后续使用
        weatherInfo = tjsondata
        -- 打印解析得到的table查看其中内容
        if result and type(tjsondata)=="table" then
            log.info("code",tjsondata["code"])
            log.info("msg",tjsondata["msg"])
            log.info("city",tjsondata["data"]["city"])
            log.info("condition",tjsondata["data"]["condition"])
        else
            log.info("testJson.decode error",errinfo)
        end
        -- 拼接TTS播放内容
        local ttsContent = tjsondata["data"]["city"]["name"].."现在的天气状况为"..tjsondata["data"]["condition"]["condition"]..",气温是"..tjsondata["data"]["condition"]["temp"].."摄氏度,风向和风力为"..tjsondata["data"]["condition"]["windDir"]..tjsondata["data"]["condition"]["windLevel"].."级,湿度为百分之"..weatherInfo["data"]["condition"]["humidity"]
        
        -- 播放天气情况
        playTts(ttsContent)
    end
end

-- 获取天气方法
local function getWeather(cityId)
    log.info("正在获取天气信息,cityId:",cityId)
    -- 发起HttpPost请求
    http.request("POST",
    "http://freecityid.market.alicloudapi.com/whapi/json/alicityweather/briefcondition",
    nil,
    {
        ["Content-Type"]="application/x-www-form-urlencoded",
        ["Authorization"]="APPCODE e10de272fdc54f01ba422f98ae0b6d58"
    },
    urlencodeTab({["cityId"]=cityId}),60000,HttpInfoHandler)
end

-- 开机立刻查询一次天气
getWeather("39")

-- 每五分钟获取一次天气情况
-- 查阅墨迹天气API使用说明得知上海市cityID为39，所以这里将39作为参数传递给函数getWeather
sys.timerLoopStart(getWeather,300000,"39")

-- 创建一个用来更新屏幕的任务
sys.taskInit(
    function()
        -- 稍等模块初始化完成
        sys.wait(4000)
        
        while true do

            -- 获取当前时间
            local tm = misc.getClock()
            -- 格式化时间显示内容
            local formattime = string.format("%02d-%02d %02d:%02d", tm.month, tm.day, tm.hour, tm.min)
            log.info("更新屏幕",formattime)

            -- 清空屏幕显示缓冲区
            disp.clear()
            -- 绘制底层的背景图片
            disp.putimage("/lua/backpng.png",0,0)
            -- 将天气信息渲染到相应位置
            disp.puttext(common.utf8ToGb2312(weatherInfo["data"]["city"]["ianatimezone"]),0,0,50)
            disp.puttext(common.utf8ToGb2312("当前时间:"),0,16)
            disp.puttext(common.utf8ToGb2312(formattime),0,32)
            disp.puttext(common.utf8ToGb2312("天气信息更新时间"),0,48)
            disp.puttext(common.utf8ToGb2312(string.sub(weatherInfo["data"]["condition"]["updatetime"],6)),0,64)
            disp.puttext(common.utf8ToGb2312("当前天气:"..weatherInfo["data"]["condition"]["condition"]),0,80)
            disp.puttext(common.utf8ToGb2312("温度:"..weatherInfo["data"]["condition"]["temp"].."摄氏度"),0,96)
            disp.puttext(common.utf8ToGb2312("风向:"..weatherInfo["data"]["condition"]["windDir"]),0,112)
            disp.puttext(common.utf8ToGb2312("风力:"..weatherInfo["data"]["condition"]["windLevel"].."级"),0,128)
            disp.puttext(common.utf8ToGb2312("湿度:"..weatherInfo["data"]["condition"]["humidity"].."%"),0,144)
            -- 更新屏幕显示内容
            disp.update()

            -- 延时60S，也就意味着刷新屏幕的操作每分钟进行一次
            sys.wait(60000)
        end
    end
)
